<?php

// Reminder: always indent with 4 spaces (no tabs).
// +---------------------------------------------------------------------------+
// | Blog Plugin 1.0                                                           |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the Blog       |
// | Plugins' PHP files.                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000-2008 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs         - tony AT tonybibbs DOT com                   |
// |          Mark Limburg       - mlimburg AT users.sourceforge DOT net       |
// |          Jason Whittenburg  - jwhitten AT securitygeeks DOT com           |
// |          Dirk Haun          - dirk AT haun-online DOT de                  |
// |          Trinity Bays       - trinity93 AT gmail DOT com                  |
// |          Oliver Spiesshofer - oliver AT spiesshofer DOT com               |
// |          Euan McKay         - info AT heatherengineering DOT com          |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is licensed under the terms of the GNU General Public License|
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                      |
// | See the GNU General Public License for more details.                      |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

if (strpos(strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false) {
    die('This file can not be used on its own.');
}

$plugin_path = $_CONF['path'] . 'plugins/blog/';
$langfile = $plugin_path . 'language/' . $_CONF['language'] . '.php';
require_once $_CONF['path_system'] . 'lib-comment.php';

if (file_exists($langfile)) {
    require_once $langfile;
} else {
    require_once $plugin_path . 'language/english.php';
}

/*
* Check and see if we need to load the plugin configuration
*/
if (!isset($_BL_CONF['blogloginrequired'])) {
    require_once $_CONF['path_system'] . 'classes/config.class.php';

    $bl_config = config::get_instance();
    $_BL_CONF = $bl_config->get_config('blog');
}

$_BL_CONF['version'] = '1.0.0';

$_TABLES['blog_items'] = $_DB_table_prefix . 'blog_items';
$_TABLES['blog_items_submission'] = $_DB_table_prefix . 'blog_items_submission';

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+

/**
* Returns the items for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
* @return   mixed   menu entry, or boolean false if disabled / hidden
*
*/
function plugin_getmenuitems_blog()
{
    global $_CONF, $_USER, $_BL_CONF, $LANG_BL;

    $anon = (empty ($_USER['uid']) || ($_USER['uid'] <= 1)) ? true : false;
    if (($_BL_CONF['hideblogmenu'] == 1) || ($anon &&
                ($_CONF['loginrequired'] || $_BL_CONF['blogloginrequired']))) {
        return false;
    }

    $menuitems[$LANG_BL[114]] = $_CONF['site_url'] . '/blog/index.php';

    return $menuitems;
}

/**
* Return headlines for New Blog section in the What's New block, if enabled
*
* @return   mixed       array(headline, byline), or boolean false is disabled
*
*/
function plugin_whatsblogupported_blog()
{
    global $_TABLES, $_BL_CONF, $LANG_BL, $LANG_WHATSBLW;

    if ( $_BL_CONF['hidenewblog'] == 0 ) {
        $retval = array( $LANG_BL[84],
                         COM_formatTimeString( $LANG_WHATSBLW['new_last'],
                                               $_BL_CONF['newbloginterval'] )
                       );
    } else {
        $retval = false;
    }

    return $retval;
}

/**
* Return new Blog items for the What's New block
*
* @return   string  HTML list of new items
*
*/
function plugin_getwhatsnew_blog()
{
    global $_CONF, $_TABLES, $_USER, $_BL_CONF, $LANG_BL;

    $retval = '';

    // Get newest items
    $sql = "SELECT bid,title FROM {$_TABLES['blog_items']} WHERE (date >= (DATE_SUB(NOW(), INTERVAL {$_BL_CONF['newbloginterval']} SECOND)))" . COM_getPermSQL( 'AND' ) . ' ORDER BY date DESC LIMIT 15';
    $result = DB_query($sql);
    $nrows = DB_numRows($result);

    if ($nrows > 0) {
        $newlinks = array();
        for ($x = 0; $x < $nrows; $x++) {
            $A = DB_fetchArray($result);
            $A['title'] = stripslashes($A['title']);
            $title = COM_truncate($A['title'], $_CONF['title_trim_length'],'...');
            $blog_title = array();
            if ($title != $A['title']) {
                $blog_title = array('title' => $A['title']);
            }

            $newblog[] = $blog_title . LB;
        }

        $retval .= COM_makeList($newblog, 'list-new-plugins');
    } else {
        $retval .= $LANG_BL[88] . '<br' . XHTML . '>' . LB;
    }

    return $retval;
}


/**
* Replace the front page if required
*
* @return   string              the page
*
*/
function plugin_centerblock_blog ($where, $page, $topic)
{
    global $blogmonth, $_BL_CONF;
    
    $display  = '';
    if ($_BL_CONF['replace_toppage']) {
        $display .= blog_list(COM_applyFilter($blogmonth), '');
        $display .= COM_siteFooter ();
    }
    return $display;
}


/**
* Create the blog list depending on the category given
*
* @param    array   $message    message(s) to display
* @return   string              the blog page
*
*/
function blog_list($blogmonth, $message)
{
    global $_CONF, $_TABLES, $_BL_CONF, $LANG_BL_ADMIN, $LANG_BL, $LANG_BL_STATS;
    
    // Reset display string
    $display = '';
    
    // Page variable for paging of results
    $page = 0;
    if (isset ($_GET['page'])) {
        $page = COM_applyFilter ($_GET['page'], true);
    }
    if ($page == 0) {
        $page = 1;
    }
    if ($page > 1) {
        $page_title = sprintf ($LANG_BL[114] . ' (%d)', $page);
    } else {
        $page_title = $LANG_BL[114];
    }
    
    // Check has access to this area
    if (empty ($_USER['username']) &&
        (($_CONF['loginrequired'] == 1) || ($_BL_CONF['blogloginrequired'] == 1))) {
        $display .= COM_siteHeader ('menu', $LANG_BL[114]);
        $display .= COM_startBlock ($LANG_LOGIN[1], '', COM_getBlockTemplate ('_msg_block', 'header'));
        $login = new Template ($_CONF['path_layout'] . 'submit');
        $login->set_file (array ('login' => 'submitloginrequired.thtml'));
        $login->set_var ( 'xhtml', XHTML );
        $login->set_var ('login_message', $LANG_LOGIN[2]);
        $login->set_var ('site_url', $_CONF['site_url']);
        $login->set_var ('lang_login', $LANG_LOGIN[3]);
        $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
        $login->parse ('output', 'login');
        $display .= $login->finish ($login->get_var ('output'));
        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
    }
    
    // Page header
    $display .= COM_siteHeader ('menu', $page_title);
    
    // Show message if there is one
    if (is_array($message) && !empty($message[0])) {
        $display .= COM_startBlock($message[0], '',
                                 COM_getBlockTemplate('_msg_block', 'header'));
        $display .= $message[1];
        $display .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
    } else if (isset($_REQUEST['msg'])) {
        $msg = COM_applyFilter($_REQUEST['msg'], true);
        if ($msg > 0) {
            $display .= COM_showMessage($msg, 'blog');
        }
    }
    
    // Setup templates for this page
    $blog_list = new Template ($_CONF['path'] . 'plugins/blog/templates/');
    $blog_list->set_file (array ('linklist' => 'blog.thtml',
                                 'item'     => 'blogdetails.thtml',
                                 'pagenav'  => 'pagenavigation.thtml'));
    $blog_list->set_var('xhtml', XHTML);
//    $blog_list->set_var('blockheader', COM_startBlock($LANG_BL[114]));
    $blog_list->set_var('layout_url', $_CONF['layout_url']);
    $blog_list->set_var('site_url', $_CONF['site_url']);
    $blog_list->set_var('lang_addblog', $LANG_BL[116]);

    // Build SQL for Blog items
    $sql = 'SELECT *';
    $from_where = " FROM {$_TABLES['blog_items']}";
    $from_where .= " WHERE date LIKE '{$blogmonth}%'";
    $from_where .= COM_getPermSQL ('AND');
    $order = ' ORDER BY date DESC';
    $limit = '';
    if ($_BL_CONF['blogperpage'] > 0) {
        if ($page < 1) {
            $start = 0;
        } else {
            $start = ($page - 1) * $_BL_CONF['blogperpage'];
        }
        $limit = ' LIMIT ' . $start . ',' . $_BL_CONF['blogperpage'];
    }
    $result = DB_query ($sql . $from_where . $order . $limit);
    $nrows = DB_numRows ($result);
    
    // Process results of query
    if ($nrows == 0) {
        // No blog to show
        $blog_list->set_var ('blog', 'No blog');
        $blog_list->set_var ('page_navigation', '');
    } else {
        // Blog to show
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray($result);
            prepare_blog_item($A, $blog_list);
            $blog_list->parse('blog', 'item', true);
        }

        $result = DB_query ('SELECT COUNT(*) AS count ' . $from_where);
        list($numlinks) = DB_fetchArray ($result);
        $pages = 0;
        if ($_BL_CONF['blogperpage'] > 0) {
            $pages = (int) ($numlinks / $_BL_CONF['blogperpage']);
            if (($numlinks % $_BL_CONF['blogperpage']) > 0 ) {
                $pages++;
            }
        }
        if ($pages > 0) {
            $blog_list->set_var('page_navigation',
                    COM_printPageNavigation($_CONF['site_url']
                        . '/blog/index.php', $page, $pages));
        } else {
            $blog_list->set_var ('page_navigation', '');
        }
    }
//    $blog_list->set_var ('blockfooter',COM_endBlock());
    $blog_list->parse ('output', 'linklist');
    $display .= $blog_list->finish ($blog_list->get_var ('output'));

    return $display;
}


/**
* Prepare a blog item for rendering
*
* @param    array   $A          blog item details
* @param    ref     $template   reference of the links template
*
*/
function prepare_blog_item ($A, &$template)
{
    global $_CONF, $_TABLES, $_BL_CONF, $LANG_ADMIN, $LANG_BL, $LANG01, $_IMAGE_TYPE;

    $author = DB_getItem($_TABLES['users'], 'fullname', "uid = {$A['owner_id']}");

    $template->set_var ('blog_title', stripslashes ($A['title']));
    $template->set_var ('blog_date', $A['date']);
    $template->set_var ('blog_author', $author);
    $template->set_var ('blog_content', stripslashes ($A['content']));
    $template->set_var ('item_url', $_CONF['site_url'] . '/blog/index.php?bid=' . $A['bid']);
    
    if ($A['commentcode'] == 0 ) {
        // comments enabled
        $num_comments = DB_count($_TABLES['comments'], array('sid', 'type' ), array($A['bid'], 'blog' ));
        $show_comment_url = $_CONF['site_url'] . '/blog/index.php?bid=' . $A['bid'] . '#comments';
        $comments = '<a href="' . $show_comment_url . '">' . $num_comments . ' ' . $LANG01[3] . '</a>';
        $template->set_var('blog_comments', $comments);
        $add_comment_url = $_CONF['site_url'] . '/comment.php?type=blog&sid=' . $A['bid'];
        $template->set_var('add_comment', '<a href="'.$add_comment_url.'">' . $LANG_BL[126] . '</a>');
    } else {
        // comments disabled
        $template->set_var('blog_comments', '');
        $template->set_var('add_comment', '');
    }
    
    if ((SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
            $A['perm_group'], $A['perm_members'], $A['perm_anon']) == 3) &&
            SEC_hasRights ('blog.edit')) {
        $editurl = $_CONF['site_admin_url']
                 . '/plugins/blog/index.php?mode=edit&amp;bid=' . $A['bid'];
        $edit_icon = "<img src=\"{$_CONF['layout_url']}/images/edit.$_IMAGE_TYPE\" "
            . "alt=\"{$LANG_ADMIN['edit']}\" title=\"{$LANG_ADMIN['edit']}\"" . XHTML . ">";
        $template->set_var ('edit_icon', COM_createLink($edit_icon, $editurl));
    } else {
        $template->set_var ('edit_icon', '');
    }
}


/**
* Implements the [blog:] autotag.
*
* @param    string  $op         operation to perform
* @param    string  $content    item (e.g. story text), including the autotag
* @param    array   $autotag    parameters used in the autotag
* @param    mixed               tag names (for $op='tagname') or formatted content
*
*/
function plugin_autotags_blog($op, $content = '', $autotag = '')
{
    global $_CONF, $_TABLES, $LANG_DIRECTION;

    if ($op == 'tagname' ) {
        return 'blog';
    } else if ($op == 'parse') {
        $bid = COM_applyFilter($autotag['parm1']);
        $url = COM_buildUrl($_CONF['site_url'] . '/blog/index.php?bid=' . $bid);
        if (empty($autotag['parm2'])) {
            $result = DB_query("SELECT url, title FROM {$_TABLES['blog_items']} WHERE bid = '$bid'");
            list($siteurl, $linktext) = DB_fetchArray($result);
        } else {
            $linktext = $autotag['parm2'];
            $siteurl = DB_getItem($_TABLES['blog_items'], 'url', "bid = '$bid'");
        }
        $class = 'ext-link';
        if ((!empty($LANG_DIRECTION)) && ($LANG_DIRECTION == 'rtl')) {
            $class .= '-rtl';
        }
        $attr = array(
                    'title' => $siteurl,
                    'class' => $class
                     );
        $link = COM_createLink($linktext, $url, $attr);
        $content = str_replace($autotag['tagstr'], $link, $content);

        return $content;
    }
}

/**
* Called by the plugin Editor to display the current plugin code version
* This may be different than the version installed and registered currently.
* If newer then you may want to run the update
*
* @return   string  version number
*
*/
function plugin_chkVersion_blog()
{
    global $_BL_CONF;

    return $_BL_CONF['version'];
}

/**
* Helper function: count number of blog items
*
* @return   array(number of blog, number of clicks);
*
*/
function blog_countLinksAndClicks ()
{
    global $_TABLES;

    $result = DB_query ("SELECT COUNT(*) AS count,SUM(hits) AS clicks FROM {$_TABLES['blog_items']}" . COM_getPermSQL ());
    $A = DB_fetchArray ($result);
    $total_links = $A['count'];
    $total_clicks = $A['clicks'];
    if (empty ($total_clicks)) {
        $total_clicks = 0;
    }

    return array ($total_links, $total_clicks);
}

/**
* Shows the statistics for the Blog plugin on stats.php.
* If $showsitestats is 1 then we are to only print the overall stats in the
* 'site statistics box' otherwise we show the detailed stats
*
* @param    int     $showsitestate  Flag to let us know which stats to get
* @param    string                  HTML for the stats section
*
*/
function plugin_showstats_blog($showsitestats)
{
    global $_CONF, $_TABLES, $LANG_BL_STATS;

    require_once ($_CONF['path_system'] . 'lib-admin.php');

    $retval = '';

    $result = DB_query ("SELECT bid,title,date FROM {$_TABLES['blog_items']} " . COM_getPermSQL () . " ORDER BY date DESC LIMIT 10");
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $header_arr = array(
            array('text'         => $LANG_BL_STATS['stats_page_title'],
                  'field'        => 'title',
                  'header_class' => 'stats-header-title'
            ),
            array('text'         => $LANG_BL_STATS['stats_date'],
                  'field'        => 'date',
                  'header_class' => 'stats-header-count',
                  'field_class'  => 'stats-list-count'
            )
        );
        $data_arr = array();
        $text_arr = array('has_menu' => false,
                          'title'    => $LANG_BL_STATS['stats_headline'],
        );
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray ($result);
            $title = stripslashes (str_replace ('$', '&#36;', $A['title']));
            $date = substr($A['date'], 0, 10);
            $data_arr[] = array('title' => $title,
                                'date' => $date
                          );
        }
        $retval .= ADMIN_simpleList ('', $header_arr, $text_arr, $data_arr);
    } else {
        $retval .= COM_startBlock ($LANG_BL_STATS['stats_headline']);
        $retval .= $LANG_BL_STATS['stats_no_hits'];
        $retval .= COM_endBlock ();
    }

    return $retval;
}

/**
* New stats plugin API function for proper integration with the site stats
*
* @return   array(item text, item count);
*
*/
function plugin_statssummary_blog()
{
    global $LANG_BL_STATS;

    list($total_links, $total_clicks) = blog_countLinksAndClicks ();

    $item_count = COM_NumberFormat ($total_links)
                . ' (' . COM_NumberFormat ($total_clicks) . ')';


    return array ($LANG_BL_STATS['blog'], $item_count);
}

/**
* Geeklog is asking us to provide any items that show up in the type
* drop-down on search.php.  Lets users search for blog.
*
* @return   array   (plugin name/entry title) pair for the dropdown
*
*/
function plugin_searchtypes_blog()
{
    global $LANG_BL;

    $tmp['blog'] = $LANG_BL[14];

    return $tmp;
}


/**
* This searches for Blog items matching the user query and returns an array for the
* header and table rows back to search.php where it will be formated and printed
*
* @param    string  $query      Keywords user is looking for
* @param    date    $datestart  Start date to get results for
* @param    date    $dateend    End date to get results for
* @param    string  $topic      The topic they were searching in
* @param    string  $type       Type of items they are searching, or 'all'
* @param    int     $author     Get all results by this author
* @param    string  $keyType    search key type: 'all', 'phrase', 'any'
* @param    int     $page       page number of current search
* @param    int     $perpage    number of results per page
* @return   object              search result object
*
*/
function plugin_dopluginsearch_blog($query, $datestart, $dateend, $topic, $type, $author, $keyType, $page, $perpage)
{
    global $_CONF, $_TABLES, $LANG_BL_SEARCH;

    if (empty ($type)) {
        $type = 'all';
    }

    // Bail if we aren't supppose to do our search
    if ($type <> 'all' AND $type <> 'blog') {
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = 'blog';
        $plugin_results->searchlabel = $LANG_BL_SEARCH['results'];

        return $plugin_results;
    }

    // blog search
    $select = 'SELECT bid,title,content,date,UNIX_TIMESTAMP(date) AS day';
    $sql = " FROM {$_TABLES['blog_items']} WHERE date <> 1 ";

    if (!empty ($query)) {
        if ($keyType == 'phrase') {
            $mysearchterm = addslashes ($query);
            $sql .= " AND (content LIKE '%$mysearchterm%')"
                 . " OR (title LIKE '%$mysearchterm%')";
        } else if ($keyType == 'all') {
            $mywords = explode (' ', $query);
            $sql .= ' AND (';
            $tmp = '';
            foreach ($mywords AS $mysearchterm) {
                $mysearchterm = addslashes (trim ($mysearchterm));
                if (!empty ($mysearchterm)) {
                    $tmp .= "(content LIKE '%$mysearchterm%')"
                         . " OR (title LIKE '%$mysearchterm%') AND ";
                }
            }
            $tmp = substr ($tmp, 0, strlen ($tmp) - 5);
            $sql .= $tmp . ')';
        } else if ($keyType == 'any') {
            $mywords = explode (' ', $query);
            $sql .= ' AND (';
            $tmp = '';
            foreach ($mywords AS $mysearchterm) {
                $mysearchterm = addslashes (trim ($mysearchterm));
                if (!empty ($mysearchterm)) {
                    $tmp .= "(content LIKE '%$mysearchterm%')"
                         . " OR (title LIKE '%$mysearchterm%') OR ";
                }
            }
            $tmp = substr ($tmp, 0, strlen ($tmp) - 4);
            $sql .= $tmp . ')';
        } else {  // quick search
            $mysearchterm = addslashes ($query);
            $sql .= " AND (content LIKE '%$mysearchterm%')"
                 . " OR (title LIKE '%$mysearchterm%')";
        }
    }

    if (!empty ($datestart) && !empty ($dateend)) {
        $delim = substr ($datestart, 4, 1);
        if (!empty($delim)) {
            $DS = explode ($delim, $datestart);
            $DE = explode ($delim, $dateend);
            $startdate = mktime (0, 0, 0, $DS[1], $DS[2], $DS[0]);
            $enddate = mktime (23, 59, 59, $DE[1], $DE[2], $DE[0]);
            $sql .= " AND (UNIX_TIMESTAMP(date) BETWEEN '$startdate' AND '$enddate')";
        }
    }

    if (!empty ($author)) {
        $sql .= "AND (owner_id = '$author')";
    }
    $sql .= COM_getPermSQL ('AND');
    $sql .= ' GROUP BY date, bid, content, title, owner_id, group_id, perm_owner, perm_group, perm_members, perm_anon ORDER BY date DESC';
    $l = ($perpage * $page) - $perpage;
    $sql .= ' LIMIT ' . $l . ',' . $perpage;

    // Perform search
    $result = DB_query ($select . $sql);
    $mycount = DB_numRows ($result);
    $result_count = DB_query ('SELECT COUNT(*)' . $sql);
    $B = DB_fetchArray ($result_count, true);

    $plugin_results = new Plugin();
    $plugin_results->plugin_name = 'blog';
    $plugin_results->searchlabel = $LANG_BL_SEARCH['results'];
    $plugin_results->addSearchHeading ($LANG_BL_SEARCH['title']);
    $plugin_results->addSearchHeading ($LANG_BL_SEARCH['content']);
    $plugin_results->addSearchHeading ($LANG_BL_SEARCH['date']);
    $plugin_results->addSearchHeading ($LANG_BL_SEARCH['author']);
    $plugin_results->num_searchresults = 0;
    $plugin_results->num_itemssearched = $B[0];
    $plugin_results->supports_paging = true;

    // NOTE if any of your data items need to be links then add them here!
    // make sure data elements are in an array and in the same order as your
    // headings above!
    for ($i = 0; $i < $mycount; $i++) {
        $A = DB_fetchArray ($result);

        $A['title'] = stripslashes ($A['title']);
        $A['content'] = stripslashes ($A['content']);
        $submitter = COM_getDisplayName ($A['owner_id']);
        if ($A['owner_id'] > 1) {
            $profile_url = $_CONF['site_url']
                     . '/users.php?mode=profile&amp;uid=' . $A['owner_id'];
            $profile = COM_createLink($submitter, $profile_url);
        } else {
            $profile = $submitter;
        }
        $row = array ($A['title'], $A['content'], substr($A['date'], 0, 10), $profile);
        $plugin_results->addSearchResult ($row);
        $plugin_results->num_searchresults++;
    }

    return $plugin_results;
}


/**
* This will put an option for Blog in the command and control block on
* moderation.php
*
* @return   mixed   array(title, url, icon), or boolean false when not allowed
*
*/
function plugin_cclabel_blog()
{
    global $_CONF, $LANG_BL;

    if (SEC_hasRights ('blog.edit')) {
        return array ($LANG_BL[14],
                      $_CONF['site_admin_url'] . '/plugins/blog/index.php',
                      plugin_geticon_blog());
    }

    return false;
}

/**
* returns the administrative option for this plugin
*
* @return   mixed   array(title, url, num. links), or void when not allowed
*
*/
function plugin_getadminoption_blog()
{
    global $_CONF, $_TABLES, $LANG_BL;

    if (SEC_hasRights ('blog.edit,blog.delete', 'OR')) {
        $total_links = DB_getItem ($_TABLES['blog_items'], 'COUNT(*)',
                                   COM_getPermSql (''));

        return array ($LANG_BL[14],
                      $_CONF['site_admin_url'] . '/plugins/blog/index.php',
                      $total_links);
    }
}

/**
* A user is about to be deleted. Update ownership of any Blog items owned
* by that user or delete them.
*
* @param    int     $uid    User id of deleted user
* @return   void
*
*/
function plugin_user_delete_blog($uid)
{
    global $_TABLES, $_BL_CONF;

    if (DB_count ($_TABLES['blog_items'], 'owner_id', $uid) == 0) {
        return;
    }

    if ($_BL_CONF['delete_blog'] == 1) {
        // delete the items
        DB_query ("DELETE FROM {$_TABLES['blog_items']} WHERE owner_id = $uid");
    } else {
        // assign ownership to a user from the Root group
        $rootgroup = DB_getItem ($_TABLES['groups'], 'grp_id',
                                 "grp_name = 'Root'");
        $result = DB_query ("SELECT DISTINCT ug_uid FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $rootgroup ORDER BY ug_uid LIMIT 1");
        $A = DB_fetchArray ($result);
        $rootuser = $A['ug_uid'];
        DB_query ("UPDATE {$_TABLES['blog_items']} SET owner_id = $rootuser WHERE owner_id = $uid");
    }
}

/**
* Do we support feeds?
*
* @return   array   id/name pairs of all supported feeds
*
*/
function plugin_getfeednames_blog()
{
    global $_TABLES;

    $feeds = array ();
    $feeds[] = array ('id' => 'all', 'name' => 'all blog items');

    return $feeds;
}

/**
* Provide feed data
*
* @param    int     $feed       feed ID
* @param    ref     $link
* @param    ref     $update
* @return   array               feed entries
*
*/
function plugin_getfeedcontent_blog($feed, &$link, &$update)
{
    global $_CONF, $_TABLES;

    $result = DB_query( "SELECT topic,limits,content_length FROM {$_TABLES['syndication']} WHERE fid = '$feed'" );
    $S = DB_fetchArray( $result );

    $result = DB_query( "SELECT bid,owner_id,title,content,UNIX_TIMESTAMP(modified) AS modified FROM " . $_TABLES['blog_items'] . blog_buildSql ($S['limits']) );

    $content = array();
    $bids = array();
    $nrows = DB_numRows( $result );

    for( $i = 0; $i < $nrows; $i++ )
    {
        $row = DB_fetchArray( $result );
        $bids[] = $row['bid'];

        $blogtitle = stripslashes( $row['title'] );
        $blogcontent = stripslashes( $row['content'] );

        $content[] = array( 'title'   => $blogtitle,
                            'summary' => $blogcontent,
                            'uid'     => $row['owner_id'],
                            'author'  => COM_getDisplayName( $row['owner_id'] ),
                            'date'    => $row['modified'],
                            'format'  => 'plaintext'
                          );
    }

    $link = $_CONF['site_url'] . '/blog/index.php';
    $update = implode( ',', $bids );

    return $content;
}

/**
* Helper function: Build part of an SQL request
*
* @param    string  $limits     limit (number of entries or number of hours)
* @return   string              part of an SQL request
*
*/
function blog_buildSql($limits)
{
    $where = '';

    $limitsql = '';
    if (!empty ($limits)) {
        if (substr ($limits, -1) == 'h') { // last xx hours
            $limitsql = '';
            $hours = substr ($limits, 0, -1);
            if (!empty ($where)) {
                $where .= ' AND ';
            }
            $where .= "modified >= DATE_SUB(NOW(),INTERVAL $hours HOUR)";
        } else {
            $limitsql = ' LIMIT ' . $limits;
        }
    }
    else
    {
        $limitsql = ' LIMIT 10';
    }

    if (!empty ($where)) {
        $where = ' WHERE ' . $where;
    }

    $sql = $where . ' ORDER BY date DESC' . $limitsql;

    return $sql;
}

/**
* Checking if Blog feeds are up to date
*
* @param    int     $feed           id of feed to be checked
* @param    string  $topic          topic (actually: cid)
* @param    string  $update_data    data describing current feed contents
* @param    string  $limit          number of entries or number of hours
* @param    string  $updated_type   (optional) type of feed to be updated
* @param    string  $updated_topic  (optional) feed's "topic" to be updated
* @param    string  $updated_id     (optional) id of entry that has changed
* @return   boolean                 true: feed data is up to date; false: isn't
*
*/
function plugin_feedupdatecheck_blog($feed, $topic, $update_data, $limit, $updated_type = '', $updated_topic = '', $updated_id = '')
{
    global $_TABLES;

    $is_current = true;

    if ($updated_type != 'blog') {
        // we're not interested
        $updated_type = '';
        $updated_topic = '';
        $updated_id = '';
    }

    $sql = "SELECT bid FROM {$_TABLES['blog_items']}" . blog_buildSql ($limit);
    $result = DB_query ($sql);
    $num = DB_numRows ($result);

    $bids = array ();
    for ($i = 0; $i < $num; $i++) {
        $A = DB_fetchArray ($result);

        if ($A['bid'] == $updated_id) {
            // this feed has to be updated - no further checks needed
            return false;
        }

        $bids[] = $A['bid'];
    }
    $current = implode (',', $bids);

    return ($current != $update_data) ? false : true;
}

/**
* Update the Blog plugin
*
* @return   int     Number of message to display (true = generic success msg)
*
*/
function plugin_upgrade_blog()
{
    // the plugin needs these function so complain when they don't exist
    if (!function_exists('PLG_uninstall') ||
            !function_exists('COM_createLink')) {
        return 3002;
    }

    // upgrades are done by the install script - return a generic error
    COM_errorLog("Plugin upgrade function not implemented");
    return 3001;
}

/**
* Geeklog informs us that we're about to be enabled or disabled
*
* @param    boolean     $enable     true = we're being enabled, false = disabled
* @return   void
*
*/
function plugin_enablestatechange_blog($enable)
{
    global $_TABLES;

    $is_enabled = $enable ? 1 : 0;

    // toggle Blog feeds
    DB_query ("UPDATE {$_TABLES['syndication']} SET is_enabled = $is_enabled WHERE type = 'blog'");
}

/**
* Counts the items that are submitted
*
* @return   int     number of items in submission queue
*
*/
function plugin_submissioncount_blog()
{
    global $_TABLES;

    $retval = 0;

    if (plugin_ismoderator_blog()) {
        $retval = DB_count ($_TABLES['blog_items_submission']);
    }

    return $retval;
}

/**
* Checks that the current user has the rights to moderate the
* plugin, returns true if this is the case, false otherwise
*
* @return        boolean       Returns true if moderator
*
*/
function plugin_ismoderator_blog()
{
    return SEC_hasRights ('blog.moderate');
}


/**
* Returns SQL & Language texts to moderation.php
*
* @return   mixed   plugin object or void if not allowed
*
*/
function plugin_itemlist_blog()
{
    global $_TABLES, $LANG_BL_SUBMIT;

    if (plugin_ismoderator_blog()) {
        $plugin = new Plugin();
        $plugin->submissionlabel = $LANG_BL_SUBMIT[11];
        $plugin->submissionhelpfile = 'cclinksubmission.html';
        $plugin->getsubmissionssql = "SELECT bid AS id,title,content,date FROM {$_TABLES['blog_items_submission']} ORDER BY title ASC";
        $plugin->addSubmissionHeading($LANG_BL_SUBMIT[2]);
        $plugin->addSubmissionHeading($LANG_BL_SUBMIT[4]);
        $plugin->addSubmissionHeading($LANG_BL_SUBMIT[3]);

        return $plugin;
    }
}

/**
* returns list of moderation values
*
* The array returned contains (in order): the row 'id' label, main plugin
* table, moderation fields (comma seperated), and plugin submission table
*
* @return       array        Returns array of useful moderation values
*
*/
function plugin_moderationvalues_blog()
{
    global $_TABLES;

    return array ('bid',
                  $_TABLES['blog_items'],
                  'bid,title,content,date,owner_id',
                  $_TABLES['blog_items_submission']);
}

/**
* Performs plugin exclusive work for items approved by moderation
*
* While moderation.php handles the actual move from blog_items_submission
* to blog_items tables, within the function we handle all other approval
* relate tasks
*
* @param    string  $id     Identifying string
* @return   string          Any wanted HTML output
*
*/
function plugin_moderationapprove_blog($id)
{
    global $_TABLES, $_USER, $_GROUPS, $_BL_CONF;

    // The blogsubmission only keeps track of the submitter's uid, but not
    // of grous and permissions. So set those to sensible defaults.

    if (isset($_GROUPS['Blog Admin'])) {
        $group_id = $_GROUPS['Blog Admin'];
    } else {
        $group_id = SEC_getFeatureGroup('blog.moderate');
    }

    $A = array();
    SEC_setDefaultPermissions($A, $_BL_CONF['default_permissions']);

    DB_query("UPDATE {$_TABLES['blog_items']} SET group_id = '$group_id', perm_owner = '{$A['perm_owner']}', perm_group = '{$A['perm_group']}', perm_members = '{$A['perm_members']}', perm_anon = '{$A['perm_anon']}' WHERE bid = '$id'");

    return '';
}

/**
* Performs plugin exclusive work for items deleted by moderation
*
* While moderation.php handles the actual removal from <plugin>submission
* table, within this function we handle all other deletion
* related tasks
*
* @param    string  $id     Identifying string
* @return   string          Any wanted HTML output
*
*/
function plugin_moderationdelete_blog($id)
{
    global $_TABLES;

    // these tables should not contain any rows with ml_id = $id
    // this is done 'just in case'
    DB_delete ($_TABLES['blog_items_submission'], 'bid', $id);

    return '';
}

/**
* Check submission form values and save if OK. Else show form again
*
* @param    array   $A  The record
* @return   string      Any wanted HTML output
*
*/
function plugin_savesubmission_blog($A)
{
    global $LANG12;

    $retval = '';

    if (!empty ($A['title']) && !empty ($A['content']) 
          && !empty ($A['year']) && !empty ($A['month']) && !empty ($A['day'])) {
        $retval = plugin_save_submit_blog($A);
    } else {
        $retval .= COM_siteHeader()
            . COM_startBlock ($LANG12[22], '', COM_getBlockTemplate ('_msg_block', 'header'))
            . $LANG12[23]
            . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'))
            . submissionform('blog')
            . COM_siteFooter ();
    }

    return $retval;
}

/**
* Shows blog submission form
*
* @return   string  HTML for the blog submission form
*
*/
function plugin_submit_blog()
{
    global $_CONF, $LANG_BL_SUBMIT, $LANG12;

    $retval = COM_startBlock ($LANG_BL_SUBMIT[1], 'submit.html');
    $date = date('c');

    $form = new Template($_CONF['path'] . 'plugins/blog/templates');
    $form->set_file('form', 'submit.thtml');
    $form->set_var('site_url', $_CONF['site_url']);
    $form->set_var('layout_url', $_CONF['layout_url']);
    $form->set_var('lang_title', $LANG_BL_SUBMIT[2]);
    $form->set_var('lang_date', $LANG_BL_SUBMIT[3]);
    $form->set_var('lang_year', $LANG_BL_SUBMIT[8]);
    $form->set_var('lang_month', $LANG_BL_SUBMIT[9]);
    $form->set_var('lang_day', $LANG_BL_SUBMIT[10]);
    $form->set_var('blog_year', substr($date, 0, 4));
    $form->set_var('blog_month', substr($date, 5, 2));
    $form->set_var('blog_day', substr($date, 8, 2));
    $form->set_var('lang_content', $LANG_BL_SUBMIT[4]);
    $form->set_var('lang_htmlnotallowed', $LANG12[35]);
    $form->set_var('lang_submit', $LANG12[8]);
    $form->set_var('xhtml', XHTML);
    $form->parse('theform', 'form');
    $retval .= $form->finish($form->get_var('theform'));
    $retval .= COM_endBlock();

    return $retval;
}

/**
* Saves a blog submission
*
* @param    array   $A  Data for that submission
* @return   string      HTML redirect
*
*/
function plugin_save_submit_blog($A)
{
    global $_CONF, $_TABLES, $_USER, $_BL_CONF, $LANG12, $_SERVER;

    $retval = '';

    $A['year'] = COM_applyFilter($A['year']);
    $A['month'] = COM_applyFilter($A['month']);
    $A['day'] = COM_applyFilter($A['day']);
    $A['title'] = addslashes(strip_tags(COM_checkWords($A['title'])));
    $A['content'] = addslashes(htmlspecialchars(COM_checkWords($A['content'])));
    $A['bid'] = addslashes(COM_makeSid());
    $A['date'] = $A['year'] . '/' . $A['month'] . '/' . $A['day'];

    COM_updateSpeedlimit('submit', $_SERVER['REMOTE_ADDR']);
    if (COM_isAnonUser()) {
        $owner_id = 1; // anonymous user
    } else {
        $owner_id = $_USER['uid'];
    }

    if (($_BL_CONF['blogsubmission'] == 1) && !SEC_hasRights('blog.submit')) {
        $result = DB_save($_TABLES['blog_items_submission'],
                    'bid,title,content,date,modified,owner_id',
                    "{$A['bid']},'{$A['title']}','{$A['content']}','{$A['date']}',NOW(),$owner_id");

        if ($_BL_CONF['notification'] == 1) {
            blog_sendNotification($_TABLES['blog_items_submission'], $A);
        }

        $retval = COM_refresh($_CONF['site_url'] . '/index.php?msg=1&amp;plugin=blog');

    } else { // add Blog item directly

        if (SEC_hasRights('blog.submit')) {
            $A['group_id'] = SEC_getFeatureGroup('blog.submit');
        } else {
            $A['group_id'] = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name = 'All Users'");
        }
        SEC_setDefaultPermissions($A, $_BL_CONF['default_permissions']);

        $result = DB_save($_TABLES['blog_items'],
                    'bid,title,content,date,modified,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon',
                    "{$A['bid']},'{$A['title']}','{$A['content']}','{$A['date']}',NOW(),$owner_id,{$A['group_id']},{$A['perm_owner']},{$A['perm_group']},{$A['perm_members']},{$A['perm_anon']}");

        if ($_BL_CONF['notification'] == 1) {
            blog_sendNotification($_TABLES['blog_items'], $A);
        }
        COM_rdfUpToDateCheck('blog', $A['bid']);

        $retval = COM_refresh($_CONF['site_url'] . '/index.php?msg=4&amp;plugin=blog');
    }

    return $retval;
}

/**
* Send an email notification for a new submission.
*
* @param    string  $table  Table where the new submission can be found
* @param    array   $A      submission data
*
*/
function blog_sendNotification ($table, $A)
{
    global $_CONF, $_TABLES, $LANG_BL, $LANG_BL_SUBMIT, $LANG08;

    $title = stripslashes ($A['title']);
    $description = stripslashes ($A['description']);

    $mailbody = "$LANG_BL_SUBMIT[8]: $title\n"
              . "$LANG_BL_SUBMIT[9]: <{$A['url']}>\n"
              . "$LANG_BL_SUBMIT[3]: {$A['category']}\n\n"
              . $description . "\n\n";
    if ($table == $_TABLES['blog_items_submission']) {
        $mailbody .= "$LANG_BL[10] <{$_CONF['site_admin_url']}/moderation.php>\n\n";
    } else {
        $mailbody .= "$LANG_BL[114] <{$_CONF['site_url']}/blog/index.php?category=" . urlencode ($A['category']) . ">\n\n";
    }
    $mailsubject = $_CONF['site_name'] . ' ' . $LANG_BL_SUBMIT[11];

    $mailbody .= "\n------------------------------\n";
    $mailbody .= "\n$LANG08[34]\n";
    $mailbody .= "\n------------------------------\n";

    COM_mail ($_CONF['site_mail'], $mailsubject, $mailbody);
}

/**
* Returns the URL of the plugin's icon
*
* @return   string      URL of the icon
*
*/
function plugin_geticon_blog()
{
    global $_CONF;

    return $_CONF['site_url'] . '/blog/images/blog.png';
}

function plugin_getListField_blog($fieldname, $fieldvalue, $A, $icon_arr)
{
    global $_CONF, $LANG_ACCESS, $LANG_BL_ADMIN;

    $retval = '';

    $access = SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']);
    if ($access > 0) {
        switch($fieldname) {
            case 'edit':
                if ($access == 3) {
                    $retval = COM_createLink(
                        $icon_arr['edit'],
                        "{$_CONF['site_admin_url']}/plugins/blog/index.php?mode=edit&amp;bid={$A['bid']}"
                    );
                }
                break;
            case 'access':
                if ($access == 3) {
                   $retval = $LANG_ACCESS['edit'];
                } else {
                   $retval = $LANG_ACCESS['readonly'];
                }
                break;
            case 'title':
                $retval = stripslashes($A['title']);
                break;
            case 'content':
                $retval = substr(stripslashes($A['content']), 0, 100);
                break;
            case 'date';
                $retval = substr($A['date'], 0, 10);
                break;
            default:
                $retval = $fieldvalue;
                break;
        }
    }

    return $retval;
}


/**
* Set template variables
*
* @param    string  $templatename   name of template, e.g. 'header'
* @param    ref     $template       reference of actual template
* @return   void
*
* Note: A plugin should use its name as a prefix for the names of its
* template variables, e.g. 'blog_xxx' and 'lang_blog_xxx'.
*
*/
function plugin_templatesetvars_blog($templatename, &$template)
{
    global $LANG_BL;

    if ($templatename == 'header') {
//        $template->set_var ('blog_xxxx', $LANG_BL[14]);
    }
}

/**
* Automatic uninstall function for plugins
*
* @return   array
*
* This code is automatically uninstalling the plugin.
* It passes an array to the core code function that removes
* tables, groups, features and php blocks from the tables.
* Additionally, this code can perform special actions that cannot be
* foreseen by the core code (interactions with other plugins for example)
*
*/
function plugin_autouninstall_blog()
{
    $out = array (
        /* give the name of the tables, without $_TABLES[] */
        'tables' => array('blog_items','blog_items_submission'),
        /* give the full name of the group, as in the db */
        'groups' => array('Blog Admin'),
        /* give the full name of the feature, as in the db */
        'features' => array('blog.edit', 'blog.moderate', 'blog.submit'),
        /* give the full name of the block, including 'phpblock_', etc */
        'php_blocks' => array('phpblock_blog', 'phpblock_latestblog'),
        /* give all vars with their name */
        'vars'=> array()
    );
    return $out;
}


// COMMENTS

/**
* Geeklog is checking to see if this plugin supports comments, tell it yes.
*
* NOTE: to support comments you must used the same date/time based ID for your
* widget.  In other words, to make primary keys for your plugin you should call
* makesid().  Comments are keyed off of that...it is a limitation on how Geeklog
* does comments.
*
*/
function plugin_commentsupport_blog()
{
    // blog will use comments
    return true;
}

/**
 * Blog saves a comment
 *
 * @param   string  $type   Plugin to save comment
 * @param   string  $title  comment title
 * @param   string  $comment comment text
 * @param   string  $id     Item id to which $cid belongs
 * @param   int     $pid    comment parent
 * @param   string  $postmode 'html' or 'text'
 * @return  mixed   false for failure, HTML string (redirect?) for success
 */
function plugin_savecomment_blog($title, $comment, $id, $pid, $postmode)
{
    global $_CONF, $_TABLES, $LANG03, $_USER;

    $retval = '';

    $commentcode = DB_getItem ($_TABLES['blog_items'], 'commentcode',
                               "bid = '$id'");
    if ($commentcode != 0) {
        return COM_refresh ($_CONF['site_url'] . '/index.php');
    }

    $ret = CMT_saveComment ($title, $comment, $id, $pid, 'blog', $postmode);
    if ($ret > 0) { // failure //FIXME: some failures should not return to comment form
        $retval .= COM_siteHeader('menu', $LANG03[1])
                . CMT_commentForm ($title, $comment, $id, $pid, 'blog',
                                   $LANG03[14], $postmode)
                . COM_siteFooter();
    } else { // success
        $retval = COM_refresh ($_CONF['site_url']
                                . "/blog/index.php?bid=$id&amp;aid=-1");
    }

    return $retval;
}

/**
 * blog: delete a comment
 *
 * @param   int     $cid    Comment to be deleted
 * @param   string  $id     Item id to which $cid belongs
 * @return  mixed   false for failure, HTML string (redirect?) for success
 */
function plugin_deletecomment_blog($cid, $id)
{
    global $_CONF, $_TABLES, $_USER;

    $retval = '';

    $has_editPermissions = SEC_hasRights ('blog.edit');
    $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['blog_items']} WHERE bid = '{$id}'");
    $A = DB_fetchArray ($result);

    if ($has_editPermissions && SEC_hasAccess ($A['owner_id'],
            $A['group_id'], $A['perm_owner'], $A['perm_group'],
            $A['perm_members'], $A['perm_anon']) == 3) {
        CMT_deleteComment($cid, $id, 'blog');
        $retval .= COM_refresh ($_CONF['site_url']
                                 . "/blog/index.php?bid=$id&amp;aid=-1");
    } else {
        COM_errorLog ("User {$_USER['username']} (IP: {$_SERVER['REMOTE_ADDR']}) "
                    . "tried to illegally delete comment $cid from blog $id");
        $retval .= COM_refresh ($_CONF['site_url'] . '/index.php');
    }

    return $retval;
}

/**
  * Plugin should display [a] comment[s]
  *
  * @param   string  $id     Unique idenifier for item comment belongs to
  * @param   int     $cid    Comment id to display (possibly including sub-comments)
  * @param   string  $title  Page/comment title
  * @param   string  $order  'ASC' or 'DSC' or blank
  * @param   string  $format 'threaded', 'nested', or 'flat'
  * @param   int     $page   Page number of comments to display
  * @param   boolean $view   True to view comment (by cid), false to display (by $pid)
  * @return  mixed   results of calling the plugin_displaycomment_ function
  */
function plugin_displaycomment_blog ($id, $cid, $title, $order, $format, $page, $view) {
    
    global $_TABLES, $LANG_ACCESS;

    $retval = '';

    $sql = "SELECT COUNT(*) AS count, owner_id, group_id, perm_owner, perm_group, perm_members, perm_anon "
         . "FROM {$_TABLES['blog_items']} WHERE (bid = '$id')" . COM_getPermSQL('AND') . ' GROUP BY bid';
    $result = DB_query ($sql);
    $A = DB_fetchArray ($result);
    $allowed = $A['count'];

    if ($allowed == 1) {
        $delete_option = (SEC_hasRights ('blog.edit') &&
                (SEC_hasAccess ($A['owner_id'], $A['group_id'],
                    $A['perm_owner'], $A['perm_group'], $A['perm_members'], $A['perm_anon']) == 3));
        $retval .= CMT_userComments ($id, $title, 'blog', $order, $format, $cid, $page, $view, $delete_option);
    } else {
        $retval .= COM_startBlock ($LANG_ACCESS['accessdenied'], '', COM_getBlockTemplate ('_msg_block', 'header'))
                . $LANG_ACCESS['storydenialmsg']
                . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
    }

    return $retval;
}

/**
  * blog - get comment url and unique id
  *
  * @return array An array containing main plugin item URL and the unqiue id
  */
function plugin_getcommenturlid_blog() {
    global $_CONF;
    return array($_CONF['site_url'] . '/blog/index.php', 'bid');
}



// PHPBLOCK FUNCTIONS


/*
*　Shows the dropdown for choosing months
*/
function phpblock_blog ()
{
    global $_CONF, $_TABLES, $LANG_BL, $blogmonth;
    
    $retval = '';
    
    $blogmonth = COM_ApplyFilter ($blogmonth);
    
    $result = DB_Query ("SELECT DISTINCT LEFT(date, 7) AS month FROM {$_TABLES['blog_items']} ORDER BY date DESC");
    $nrows = DB_numRows ($result);
    
    if ($nrows == 0) {
        $retval .= $LANG_BL[124];
    } else {
        $retval .= '<form action="'.$_CONF['site_url'].'/blog/index.php" method="post">';
        $retval .= '<select onchange="submit()" name="blogmonth">';
        $retval .= '<option value=""';
        if ($blogmonth == '') {
            $retval .= ' selected="selected"';
        }
        $retval .= '>' . $LANG_BL[125] . '</option>' . LB;
        
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray($result);
            $retval .= '<option value="' . $A['month'] . '"';
            if ($A['month'] == $blogmonth) {
                $retval .= ' selected="selected"';
            }
            $retval .= '>' . $A['month'] . '</option>' . LB;
        }
        $retval .= '</select>';
        $retval .= '</form>';
    }
    
    return $retval;
}


/*
* Shows a list of the latest added/updated blog
*/
function phpblock_latestblog ()
{
    global $_CONF, $_TABLES, $LANG_BL, $blogmonth;
    
    $retval = '';
    
    $blogmonth = COM_ApplyFilter ($blogmonth);
    
    $result = DB_Query ("SELECT title,date FROM {$_TABLES['blog_items']} ORDER BY modified DESC LIMIT 10");
    $nrows = DB_numRows ($result);
    
    if ($nrows == 0) {
        $retval .= $LANG_BL[124];
    } else {
        $retval .= '<ul>';
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray($result);
            $retval .= '<li>' . substr($A['title'],0,24) . '</li>' . LB;
        }
        $retval .= '</ul>';
    }
    
    return $retval;
}

?>
