<?php

// Reminder: always indent with 4 spaces (no tabs).
// +---------------------------------------------------------------------------+
// | Blog Plugin 1.0                                                           |
// +---------------------------------------------------------------------------+
// | install_defaults.php                                                      |
// |                                                                           |
// | Initial Installation Defaults used when loading the online configuration  |
// | records. These settings are only used during the initial installation     |
// | and not referenced any more once the plugin is installed.                 |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000-2008 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs         - tony AT tonybibbs DOT com                   |
// |          Mark Limburg       - mlimburg AT users.sourceforge DOT net       |
// |          Jason Whittenburg  - jwhitten AT securitygeeks DOT com           |
// |          Dirk Haun          - dirk AT haun-online DOT de                  |
// |          Trinity Bays       - trinity93 AT gmail DOT com                  |
// |          Oliver Spiesshofer - oliver AT spiesshofer DOT com               |
// |          Euan McKay         - info AT heatherengineering DOT com          |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is licensed under the terms of the GNU General Public License|
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                      |
// | See the GNU General Public License for more details.                      |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

if (strpos(strtolower($_SERVER['PHP_SELF']), 'install_defaults.php') !== false) {
    die('This file can not be used on its own!');
}

/*
 * Blog default settings
 *
 * Initial Installation Defaults used when loading the online configuration
 * records. These settings are only used during the initial installation
 * and not referenced any more once the plugin is installed
 *
 */

/**
* the Blog plugin's config array
*/
global $_BL_DEFAULT;
$_BL_DEFAULT = array();

/**
 * this lets you select which functions are available for registered users only
 */
$_BL_DEFAULT['blogloginrequired'] = 0;

/**
 * Submission Settings
 * enable (set to 1) or disable (set to 0) submission queues:
 */
$_BL_DEFAULT['blogsubmission']  = 1;

/**
 * Following times are in seconds
 */
$_BL_DEFAULT['newbloginterval']    = 1209600; // = 14 days

/**
 * Set to 1 to hide a section from the What's New block:
 */
$_BL_DEFAULT['hidenewblog']    = 0;

/**
 * Set to 1 to hide the "Blog" entry from the top menu:
 */
$_BL_DEFAULT['hideblogmenu']    = 0;

/**
 * items per page
 */
$_BL_DEFAULT['blogperpage'] = 10;

/**
 * notify when a new item was submitted
 */
$_BL_DEFAULT['notification'] = 0;

/**
 * should we remove items submitted by users if account is removed? (1)
 * or change owner to root (0)
 */
$_BL_DEFAULT['delete_blog'] = 0;

/** What to show after a Blog has been saved? Possible choices:
 * 'item' -> forward to the item
 * 'list' -> display the admin-list of Blog
 * 'plugin' -> display the public homepage of the Blog plugin
 * 'home' -> display the site homepage
 * 'admin' -> display the site admin homepage
 */
$_BL_DEFAULT['aftersave'] = 'list';

/**
 * Define default permissions for new items created from the Admin panel.
 * Permissions are perm_owner, perm_group, perm_members, perm_anon (in that
 * order). Possible values:<br>
 * - 3 = read + write permissions (perm_owner and perm_group only)
 * - 2 = read-only
 * - 0 = neither read nor write permissions
 * (a value of 1, ie. write-only, does not make sense and is not allowed)
 */
$_BL_DEFAULT['default_permissions'] = array (3, 2, 2, 2);


$_BL_DEFAULT['replace_toppage'] = 0;


/**
* Initialize Blog plugin configuration
*
* Creates the database entries for the configuation if they don't already
* exist. Initial values will be taken from $_BL_CONF if available (e.g. from
* an old config.php), uses $_BL_DEFAULT otherwise.
*
* @return   boolean     true: success; false: an error occurred
*
*/
function plugin_initconfig_blog()
{
    global $_BL_CONF, $_BL_DEFAULT;

    if (is_array($_BL_CONF) && (count($_BL_CONF) > 1)) {
        $_BL_DEFAULT = array_merge($_BL_DEFAULT, $_BL_CONF);
    }

    $c = config::get_instance();
    if (!$c->group_exists('blog')) {

        $c->add('sg_main', NULL, 'subgroup', 0, 0, NULL, 0, true, 'blog');
        $c->add('fs_public', NULL, 'fieldset', 0, 0, NULL, 0, true, 'blog');
        $c->add('blogloginrequired', $_BL_DEFAULT['blogloginrequired'],
                'select', 0, 0, 0, 10, true, 'blog');
        $c->add('blogperpage', $_BL_DEFAULT['blogperpage'], 'text',
                0, 0, 0, 30, true, 'blog');
        $c->add('fs_admin', NULL, 'fieldset', 0, 1, NULL, 0, true, 'blog');
        $c->add('hidenewblog', $_BL_DEFAULT['hidenewblog'], 'select',
                0, 1, 0, 60, true, 'blog');
        $c->add('newbloginterval', $_BL_DEFAULT['newbloginterval'], 'text',
                0, 1, 0, 70, true, 'blog');
        $c->add('hideblogmenu', $_BL_DEFAULT['hideblogmenu'], 'select',
                0, 1, 0, 80, true, 'blog');
        $c->add('blogsubmission', $_BL_DEFAULT['blogsubmission'], 'select',
                0, 1, 0, 90, true, 'blog');
        $c->add('notification', $_BL_DEFAULT['notification'], 'select',
                0, 1, 0, 100, true, 'blog');
        $c->add('delete_blog', $_BL_DEFAULT['delete_blog'], 'select',
                0, 1, 0, 110, true, 'blog');
        $c->add('aftersave', $_BL_DEFAULT['aftersave'], 'select',
                0, 1, 9, 120, true, 'blog');
        $c->add('replace_toppage', $_BL_DEFAULT['replace_toppage'], 'select',
                0, 0, 0, 130, true, 'blog');

        $c->add('fs_permissions', NULL, 'fieldset', 0, 2, NULL, 0, true, 'blog');
        $c->add('default_permissions', $_BL_DEFAULT['default_permissions'],
                '@select', 0, 2, 12, 140, true, 'blog');

    }

    return true;
}

?>
