<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Blog Plugin 1.0                                                           |
// +---------------------------------------------------------------------------+
// | index.php                                                                 |
// |                                                                           |
// | This is the main page for the Geeklog Blog Plugin                         |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000-2008 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
// |          Jason Whittenburg - jwhitten AT securitygeeks DOT com            |
// |          Tom Willett       - tomw AT pigstye DOT net                      |
// |          Trinity Bays      - trinity93 AT gmail DOT com                   |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// |          Euan McKay         - info AT heatherengineering DOT com          |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

require_once '../lib-common.php';

if (!in_array('blog', $_PLUGINS)) {
    echo COM_refresh($_CONF['site_url'] . '/index.php');
    exit;
}


/* 
 * Functions for displaying list are in functions.php 
 * so that they can also be called from there when replacing whole front page.
 */


/**
* Prepare a blog item for rendering
*
* @param    array   $A          blog item details
* @param    ref     $template   reference of the blog item template
*
*/
function show_blog_item ($bid, $comment_order = 'ASC', $comment_mode = 'nested')
{
    global $_CONF, $_TABLES, $_BL_CONF, $LANG_ADMIN, $LANG_BL, $LANG01, $_IMAGE_TYPE, $PLG_blog_MESSAGE5, $LANG_LOGIN;

    // Reset display string
    $display = '';

    // Build SQL for Blog items
    $sql = "SELECT * FROM {$_TABLES['blog_items']}  WHERE bid='{$bid}' " . COM_getPermSQL ('AND');
    $result = DB_query ($sql);
    $nrows = DB_numRows ($result);
    $A = DB_fetchArray($result);
    
    if ($nrows == 0) {
        // No blog to show
        $display .= COM_siteHeader ('menu', $LANG_BL[114]);
        $display .= COM_startBlock ($LANG_LOGIN[1], '', COM_getBlockTemplate ('_msg_block', 'header'));
        $display .= $PLG_blog_MESSAGE5;
        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
    } else {
        // show item
        $page_title = $LANG_BL[114];
        $display .= COM_siteHeader ('menu', $page_title);
        $author = DB_getItem($_TABLES['users'], 'fullname', "uid = {$A['owner_id']}");
    
        // Setup templates for this page
        $template = new Template ($_CONF['path'] . 'plugins/blog/templates/');
        $template->set_file (array ('item' => 'blogitem.thtml'));
        $template->set_var('xhtml', XHTML);
        $template->set_var('blockheader', COM_startBlock($LANG_BL[114]));
        $template->set_var('layout_url', $_CONF['layout_url']);
        $template->set_var('site_url', $_CONF['site_url']);
        $template->set_var('lang_addblog', $LANG_BL[116]);
        $template->set_var ('blog_title', stripslashes ($A['title']));
        $template->set_var ('blog_date', $A['date']);
        $template->set_var ('blog_author', $author);
        $template->set_var ('blog_content', stripslashes ($A['content']));
        
        
        // comments
        if ($A['commentcode'] == 0 ) {
            // comments enabled
            $add_comment_url = $_CONF['site_url'] . '/comment.php?type=blog&sid=' . $bid;
            $template->set_var('add_comment', '<a href="'.$add_comment_url.'">' . $LANG_BL[126] . '</a>');
            $delete_option = (SEC_hasRights('blog.edit') &&
                              SEC_hasAccess($A['owner_id'], $A['group_id'], $A['perm_owner'], $A['perm_group'],
                                            $A['perm_members'], $A['perm_anon']) == 3 ? true : false);
            $template->set_var('comments', CMT_userComments($bid, $page_title, 'blog',
                                        $comment_order, $comment_mode, 0, 1, false,
                                        $delete_option, $A['commentcode']));
        } else {
            // comments disabled
            $template->set_var('blog_comments', '');
        }
        
        // edit icon
        if ((SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                $A['perm_group'], $A['perm_members'], $A['perm_anon']) == 3) &&
                SEC_hasRights ('blog.edit')) {
            $editurl = $_CONF['site_admin_url']
                     . '/plugins/blog/index.php?mode=edit&amp;bid=' . $A['bid'];
            $edit_icon = "<img src=\"{$_CONF['layout_url']}/images/edit.$_IMAGE_TYPE\" "
                . "alt=\"{$LANG_ADMIN['edit']}\" title=\"{$LANG_ADMIN['edit']}\"" . XHTML . ">";
            $template->set_var ('edit_icon', COM_createLink($edit_icon, $editurl));
        } else {
            $template->set_var ('edit_icon', '');
        }
        
        // close out template
        $template->parse ('output', 'item');
        $display .= $template->finish ($template->get_var ('output'));
    }

    return $display;
}

// MAIN

$display = '';
$mode = '';
if (isset ($_REQUEST['mode'])) {
    $mode = $_REQUEST['mode'];
}
if (isset ($_REQUEST['blogmonth'])) {
    $blogmonth = $_REQUEST['blogmonth'];
}
if (isset ($_REQUEST['bid'])) {
    $bid = COM_applyFilter($_REQUEST['bid']);
}

// from comments display refresh:
if (isset($_POST['order'])) {
    $comment_order = COM_applyFilter($_POST['order']);
    $comment_mode  = COM_applyFilter($_POST['mode']);
    $page = COM_applyFilter($_POST['id']);
    if ((strcasecmp($comment_order, 'ASC') != 0) && (strcasecmp($comment_order, 'DESC') != 0)) {
        $comment_order = '';
    }
} else {
    $comment_order = '';
    $comment_mode  = '';
}

$message = array();
if (($mode == 'report') && (isset($_USER['uid']) && ($_USER['uid'] > 1))) {
    if (!empty($bid)) {
        $bidsl = addslashes($bid);
        $result = DB_query("SELECT url, title FROM {$_TABLES['blog_items']} WHERE bid = '$bidsl'");
        list($url, $title) = DB_fetchArray($result);

        $editurl = $_CONF['site_admin_url'] . '/plugins/blog/index.php?mode=edit&bid=' . $bid;
        $msg = $LANG_BL[119] . LB . LB . "$title, <$url>". LB . LB
             .  $LANG_BL[120] . LB . '<' . $editurl . '>' . LB . LB
             .  $LANG_BL[121] . $_USER['username'] . ', IP: '
             . $_SERVER['REMOTE_ADDR'];
        COM_mail($_CONF['site_mail'], $LANG_BL[118], $msg);
        $message = array($LANG_BL[123], $LANG_BL[122]);
    }
}

if (empty ($_USER['username']) &&
    (($_CONF['loginrequired'] == 1) || ($_BL_CONF['blogloginrequired'] == 1))) {
    $display .= COM_siteHeader ('menu', $LANG_BL[114]);
    $display .= COM_startBlock ($LANG_LOGIN[1], '',
                                COM_getBlockTemplate ('_msg_block', 'header'));
    $login = new Template ($_CONF['path_layout'] . 'submit');
    $login->set_file (array ('login' => 'submitloginrequired.thtml'));
    $login->set_var ( 'xhtml', XHTML );
    $login->set_var ('login_message', $LANG_LOGIN[2]);
    $login->set_var ('site_url', $_CONF['site_url']);
    $login->set_var ('lang_login', $LANG_LOGIN[3]);
    $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
    $login->parse ('output', 'login');
    $display .= $login->finish ($login->get_var ('output'));
    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
} elseif (!empty($bid)) {
    $display .= show_blog_item($bid, $comment_order, $comment_mode);
} else {
    $display .= blog_list(COM_applyFilter($blogmonth), $message);
}

$display .= COM_siteFooter ();

echo $display;

?>
